package de.intevation.flys.exports;

import java.text.NumberFormat;

import org.apache.log4j.Logger;

import au.com.bytecode.opencsv.CSVWriter;

import de.intevation.artifacts.Artifact;

import de.intevation.flys.artifacts.WINFOArtifact;
import de.intevation.flys.artifacts.model.WQCKms;
import de.intevation.flys.artifacts.model.WQKms;

/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DischargeLongitudinalSectionExporter extends WaterlevelExporter {

    /** The logger used in this exporter.*/
    private static Logger logger =
        Logger.getLogger(DischargeLongitudinalSectionExporter.class);


    public static final String CSV_KM_HEADER =
        "export.discharge.longitudinal.section.csv.header.km";

    public static final String CSV_W_HEADER =
        "export.discharge.longitudinal.section.csv.header.w";

    public static final String CSV_CW_HEADER =
        "export.discharge.longitudinal.section.csv.header.cw";

    public static final String CSV_Q_HEADER =
        "export.discharge.longitudinal.section.csv.header.q";

    public static final String DEFAULT_CSV_KM_HEADER = "Fluss-Km";
    public static final String DEFAULT_CSV_W_HEADER  = "W [NN + m]";
    public static final String DEFAULT_CSV_CW_HEADER = "W korr.";
    public static final String DEFAULT_CSV_Q_HEADER  = "Q [m³/s]";


    @Override
    protected void addData(Artifact artifact) {
        WINFOArtifact winfo = (WINFOArtifact) artifact;
        WQKms[]       wqkms = winfo.getDischargeLongitudinalSectionData();

        logger.debug("Got " + wqkms != null ? wqkms.length : 0 + " WQKms obj.");

        data.add(wqkms);
    }


    @Override
    protected void writeCSVHeader(CSVWriter writer) {
        logger.info("WaterlevelExporter.writeCSVHeader");

        writer.writeNext(new String[] {
            msg(CSV_KM_HEADER, DEFAULT_CSV_KM_HEADER),
            msg(CSV_W_HEADER, DEFAULT_CSV_W_HEADER),
            msg(CSV_CW_HEADER, DEFAULT_CSV_CW_HEADER),
            msg(CSV_Q_HEADER, DEFAULT_CSV_Q_HEADER)
        });
    }

    @Override
    protected void wQKms2CSV(CSVWriter writer, WQKms wqkms) {
        logger.debug("WaterlevelExporter.wQKms2CSV");

        int      size   = wqkms.size();
        double[] result = new double[4];

        NumberFormat kmf = getKmFormatter();
        NumberFormat wf  = getWFormatter();
        NumberFormat qf  = getQFormatter();

        for (int i = 0; i < size; i ++) {
            result = wqkms.get(i, result);

            String wc = "";
            if (wqkms instanceof WQCKms) {
                wc = wf.format(result[3]);
            }

            writer.writeNext(new String[] {
                kmf.format(result[2]),
                wf.format(result[0]),
                wc,
                qf.format(result[1])
            });
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
